@@ -11,7 +11,7 @@
 
 //  See http://www.boost.org/libs/config for most recent version.
 //
-//  Revision $Id: config_info.cpp 53445 2009-05-30 11:22:59Z bemandawes $
+//  Revision $Id$
 //
 
 #include <boost/config.hpp>
@@ -27,6 +27,10 @@
 #include <unistd.h>
 #endif
 
+#if defined(__MINGW32__)
+#  include <_mingw.h>
+#endif
+
 static unsigned int indent = 4;
 static unsigned int width = 40;
 
@@ -139,18 +143,53 @@ void print_compiler_macros()
   PRINT_MACRO(_WCHAR_T_DEFINED);
 #endif
   // MSVC macros:
+  PRINT_MACRO(_ALIGNED_NEW_SUPPORTED);
+  PRINT_MACRO(__ATOM__);
+  PRINT_MACRO(__AVX__);
+  PRINT_MACRO(__AVX2__);
+  PRINT_MACRO(_CHAR_UNSIGNED);
+  PRINT_MACRO(_CLR_VER);
+  PRINT_MACRO(_CONTROL_FLOW_GUARD);
+  PRINT_MACRO(__cplusplus_cli);
+  PRINT_MACRO(__cplusplus_winrt);
   PRINT_MACRO(_CPPRTTI);
+  PRINT_MACRO(_CPPUNWIND);
   PRINT_MACRO(_DLL);
+  PRINT_MACRO(_INLINE_VARIABLES_SUPPORTED);
+  PRINT_MACRO(_ISO_VOLATILE);
+  PRINT_MACRO(_M_AMD64);
+  PRINT_MACRO(_M_ARM);
+  PRINT_MACRO(_M_ARM_ARMV7VE);
+  PRINT_MACRO(_M_ARM_FP);
+  PRINT_MACRO(_M_ARM64);
+  PRINT_MACRO(_M_CEE);
+  PRINT_MACRO(_M_CEE_PURE);
+  PRINT_MACRO(_M_CEE_SAFE);
+  PRINT_MACRO(_M_FP_EXCEPT);
+  PRINT_MACRO(_M_FP_FAST);
+  PRINT_MACRO(_M_FP_PRECISE);
+  PRINT_MACRO(_M_FP_STRICT);
+  PRINT_MACRO(_M_IX86);
+  PRINT_MACRO(_M_IX86_FP);
+  PRINT_MACRO(_M_X64);
   PRINT_MACRO(_M_ALPHA);
   PRINT_MACRO(_M_MPPC);
   PRINT_MACRO(_M_MRX000);
   PRINT_MACRO(_M_PPC);
+  PRINT_MACRO(_MANAGED);
+  PRINT_MACRO(_MSC_BUILD);
   PRINT_MACRO(_MFC_VER);
   PRINT_MACRO(_MSC_EXTENSIONS);
   PRINT_MACRO(_MSC_VER);
   PRINT_MACRO(_MSC_FULL_VER);
+  PRINT_MACRO(_MSVC_LANG);
+  PRINT_MACRO(_MSVC_WARNING_LEVEL);
+  PRINT_MACRO(__MSVC_RUNTIME_CHECKS);
   PRINT_MACRO(_MT);
   PRINT_MACRO(_NATIVE_WCHAR_T_DEFINED);
+  PRINT_MACRO(_NOEXCEPT_TYPES_SUPPORTED);
+  PRINT_MACRO(_OPENMP);
+  PRINT_MACRO(_PREFAST_);
   // GNUC options:
   PRINT_MACRO(__GNUC__);
   PRINT_MACRO(__GNUC_MINOR__);
@@ -188,6 +227,33 @@ void print_compiler_macros()
   PRINT_MACRO(__hppa);
   PRINT_MACRO(__CYGWIN__);
   PRINT_MACRO(__MINGW32__);
+  PRINT_MACRO(__GXX_RTTI);
+  PRINT_MACRO(__alpha__);
+  PRINT_MACRO(__amd64__);
+  PRINT_MACRO(__arm__);
+  PRINT_MACRO(__aarch64__);
+  PRINT_MACRO(__bfin);
+  PRINT_MACRO(__convex__);
+  PRINT_MACRO(__epiphany__);
+  PRINT_MACRO(__hppa__);
+  PRINT_MACRO(__ia64__);
+  PRINT_MACRO(__IA64);
+  PRINT_MACRO(__IA64__);
+  PRINT_MACRO(__m68k__);
+  PRINT_MACRO(__mips__);
+  PRINT_MACRO(__powerpc);
+  PRINT_MACRO(__powerpc__);
+  PRINT_MACRO(__powerpc64__);
+  PRINT_MACRO(__POWERPC__);
+  PRINT_MACRO(__ppc__);
+  PRINT_MACRO(__ppc64__);
+  PRINT_MACRO(__PPC__);
+  PRINT_MACRO(__PPC64__);
+  PRINT_MACRO(_ARCH_PPC);
+  PRINT_MACRO(_ARCH_PPC64);
+  PRINT_MACRO(__sh__);
+  PRINT_MACRO(__370__);
+  PRINT_MACRO(__THW_370__);
   // HP aCC:
   PRINT_MACRO(__HP_aCC);
   PRINT_MACRO(_HPACC_);
@@ -289,6 +355,31 @@ void print_compiler_macros()
   PRINT_MACRO(_OPENMPT);
   PRINT_MACRO(_PGO_INSTRUMENT);
   PRINT_MACRO(__QMSPP_); 
+  PRINT_MACRO(__INTEL_RTTI__);
+  PRINT_MACRO(__INTEL_CXX11_MODE__);
+
+  // Cray options:
+  PRINT_MACRO(_CRAYC); 
+  PRINT_MACRO(_RELEASE); 
+  PRINT_MACRO(cray); 
+  PRINT_MACRO(CRAY); 
+  PRINT_MACRO(CRAY1); 
+  PRINT_MACRO(_CRAY1); 
+  PRINT_MACRO(_CRAYMPP); 
+  PRINT_MACRO(_CRAYT3E); 
+  PRINT_MACRO(_CRAYIEEE); 
+  PRINT_MACRO(_ADDR32); 
+  PRINT_MACRO(_ADDR64); 
+  PRINT_MACRO(_LD64); 
+  PRINT_MACRO(_FASTMD); 
+  PRINT_MACRO(_MAXVL); 
+
+  // clang options:
+  PRINT_MACRO(__clang__); 
+  PRINT_MACRO(__clang_major__);
+  PRINT_MACRO(__clang_minor__);
+  PRINT_MACRO(__clang_version__);
+  PRINT_MACRO(__clang_patchlevel__);
 
   // misc compilers not covered so far:
   PRINT_MACRO(__USLC__);
@@ -305,6 +396,19 @@ void print_compiler_macros()
   PRINT_MACRO(__QNXNTO__);
   PRINT_MACRO(__QNX__);
   PRINT_MACRO(_NTO_VERSION);
+  PRINT_MACRO(__OPEN64__);
+  PRINT_MACRO(__open64);
+  PRINT_MACRO(__NVCC__);
+  PRINT_MACRO(__CUDACC__);
+  PRINT_MACRO(__CUDACC_RDC__);
+  PRINT_MACRO(__CUDACC_VER_MAJOR__);
+  PRINT_MACRO(__CUDACC_VER_MINOR__);
+  PRINT_MACRO(__CUDACC_VER_BUILD__);
+  PRINT_MACRO(__CUDACC_VER__);
+
+  // Android:
+  PRINT_MACRO(ANDROID);
+  PRINT_MACRO(__ANDROID__);
 }
 
 void print_stdlib_macros()
@@ -537,10 +641,35 @@ void print_stdlib_macros()
    #endif
    // Dinkumware options:
    PRINT_MACRO(_CPPLIB_VER);
+   PRINT_MACRO(_MSVC_STL_VERSION); // VS2017 15.5+
+   PRINT_MACRO(_MSVC_STL_UPDATE);  // VS2017 15.5+
    PRINT_MACRO(_GLOBAL_USING);
    PRINT_MACRO(_HAS_EXCEPTIONS);
    PRINT_MACRO(_HAS_MEMBER_TEMPLATES_REBIND);
    PRINT_MACRO(_HAS_TEMPLATE_PARTIAL_ORDERING);
+   // https://blogs.msdn.microsoft.com/vcblog/2016/08/12/stl-fixes-in-vs-2015-update-3/
+   PRINT_MACRO(_HAS_CXX17);
+   PRINT_MACRO(_HAS_AUTO_PTR_ETC);
+   PRINT_MACRO(_HAS_OLD_IOSTREAMS_MEMBERS);
+   PRINT_MACRO(_HAS_FUNCTION_ASSIGN);
+   PRINT_MACRO(_HAS_TR1_NAMESPACE);
+   PRINT_MACRO(_HAS_IDENTITY_STRUCT);
+   // VS2017 15.5+
+   PRINT_MACRO(_HAS_STATIC_RTTI);
+   PRINT_MACRO(_HAS_UNEXPECTED);
+   PRINT_MACRO(_HAS_STD_BYTE);
+   PRINT_MACRO(_HAS_FUNCTION_ALLOCATOR_SUPPORT);
+   PRINT_MACRO(_HAS_TR2_SYS_NAMESPACE);
+   PRINT_MACRO(_ENFORCE_MATCHING_ALLOCATORS);
+   PRINT_MACRO(_HAS_HAS_UNIQUE_OBJECT_REPRESENTATIONS);
+   PRINT_MACRO(_HAS_INLINE_VARIABLES);
+   PRINT_MACRO(_HAS_ALIGNED_NEW);
+   PRINT_MACRO(_HAS_NOEXCEPT_FUNCTION_TYPES);
+   PRINT_MACRO(_ITERATOR_DEBUG_LEVEL);
+   PRINT_MACRO(_HAS_ITERATOR_DEBUGGING);
+   PRINT_MACRO(_ITERATOR_DEBUG_ARRAY_OVERLOADS);
+   // Libc++:
+   PRINT_MACRO(_LIBCPP_VERSION);
    // STLPort and generic SGI STL options:
    PRINT_MACRO(__SGI_STL_NO_ARROW_OPERATOR);
    PRINT_MACRO(__SGI_STL_OWN_IOSTREAMS);
@@ -718,6 +847,8 @@ void print_stdlib_macros()
    PRINT_MACRO(_GLIBCXX_MEM_LIMITS);
    PRINT_MACRO(_GLIBCXX_HOSTED);
    PRINT_MACRO(_GLIBCXX_SJLJ_EXCEPTIONS);
+   PRINT_MACRO(_GLIBCXX_RELEASE);
+   PRINT_MACRO(_GLIBCXX_USE_FLOAT128);
 
    // Modena C++ standard library
    PRINT_MACRO(MSIPL_ANSI_HEADER);
@@ -792,6 +923,8 @@ void print_platform_macros()
    PRINT_MACRO(_THREAD_SAFE);
    PRINT_MACRO(_XOPEN_SOURCE_EXTENDED);
    PRINT_MACRO(XPG);
+   PRINT_MACRO(__MINGW32_MAJOR_VERSION);
+   PRINT_MACRO(__MINGW32_MINOR_VERSION);
    // POSIX:
    PRINT_MACRO(_POSIX_ADVISORY_INFO);
    PRINT_MACRO(_POSIX_ASYNCHRONOUS_IO);
@@ -898,6 +1031,7 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_DISABLE_THREADS);
    PRINT_MACRO(BOOST_DISABLE_WIN32);
    PRINT_MACRO(BOOST_HAS_THREADS);
+   PRINT_MACRO(BOOST_WINDOWS);
 
    // BEGIN GENERATED BLOCK DO NOT EDIT THIS!!!!!!
    PRINT_MACRO(BOOST_BCB_PARTIAL_SPECIALIZATION_BUG);
@@ -905,12 +1039,14 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_FUNCTION_SCOPE_USING_DECLARATION_BREAKS_ADL);
    PRINT_MACRO(BOOST_HAS_BETHREADS);
    PRINT_MACRO(BOOST_HAS_CLOCK_GETTIME);
-   PRINT_MACRO(BOOST_HAS_CONCEPTS);
    PRINT_MACRO(BOOST_HAS_DIRENT_H);
    PRINT_MACRO(BOOST_HAS_EXPM1);
+   PRINT_MACRO(BOOST_HAS_FLOAT128);
    PRINT_MACRO(BOOST_HAS_FTIME);
+   PRINT_MACRO(BOOST_HAS_GETSYSTEMTIMEASFILETIME);
    PRINT_MACRO(BOOST_HAS_GETTIMEOFDAY);
    PRINT_MACRO(BOOST_HAS_HASH);
+   PRINT_MACRO(BOOST_HAS_INT128);
    PRINT_MACRO(BOOST_HAS_LOG1P);
    PRINT_MACRO(BOOST_HAS_LONG_LONG);
    PRINT_MACRO(BOOST_HAS_MACRO_USE_FACET);
@@ -919,6 +1055,7 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_HAS_NL_TYPES_H);
    PRINT_MACRO(BOOST_HAS_NRVO);
    PRINT_MACRO(BOOST_HAS_PARTIAL_STD_ALLOCATOR);
+   PRINT_MACRO(BOOST_HAS_PRAGMA_DETECT_MISMATCH);
    PRINT_MACRO(BOOST_HAS_PTHREADS);
    PRINT_MACRO(BOOST_HAS_PTHREAD_DELAY_NP);
    PRINT_MACRO(BOOST_HAS_PTHREAD_MUTEXATTR_SETTYPE);
@@ -931,85 +1068,136 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_HAS_STATIC_ASSERT);
    PRINT_MACRO(BOOST_HAS_STDINT_H);
    PRINT_MACRO(BOOST_HAS_STLP_USE_FACET);
-   PRINT_MACRO(BOOST_HAS_TR1_ARRAY);
-   PRINT_MACRO(BOOST_HAS_TR1_BIND);
-   PRINT_MACRO(BOOST_HAS_TR1_COMPLEX_INVERSE_TRIG);
-   PRINT_MACRO(BOOST_HAS_TR1_COMPLEX_OVERLOADS);
-   PRINT_MACRO(BOOST_HAS_TR1_FUNCTION);
-   PRINT_MACRO(BOOST_HAS_TR1_HASH);
-   PRINT_MACRO(BOOST_HAS_TR1_MEM_FN);
-   PRINT_MACRO(BOOST_HAS_TR1_RANDOM);
-   PRINT_MACRO(BOOST_HAS_TR1_REFERENCE_WRAPPER);
-   PRINT_MACRO(BOOST_HAS_TR1_REGEX);
-   PRINT_MACRO(BOOST_HAS_TR1_RESULT_OF);
-   PRINT_MACRO(BOOST_HAS_TR1_SHARED_PTR);
-   PRINT_MACRO(BOOST_HAS_TR1_TUPLE);
-   PRINT_MACRO(BOOST_HAS_TR1_TYPE_TRAITS);
-   PRINT_MACRO(BOOST_HAS_TR1_UNORDERED_MAP);
-   PRINT_MACRO(BOOST_HAS_TR1_UNORDERED_SET);
-   PRINT_MACRO(BOOST_HAS_TR1_UTILITY);
    PRINT_MACRO(BOOST_HAS_TWO_ARG_USE_FACET);
    PRINT_MACRO(BOOST_HAS_UNISTD_H);
    PRINT_MACRO(BOOST_HAS_VARIADIC_TMPL);
    PRINT_MACRO(BOOST_HAS_WINTHREADS);
    PRINT_MACRO(BOOST_MSVC6_MEMBER_TEMPLATES);
    PRINT_MACRO(BOOST_MSVC_STD_ITERATOR);
-   PRINT_MACRO(BOOST_NO_0X_HDR_ARRAY);
-   PRINT_MACRO(BOOST_NO_0X_HDR_CHRONO);
-   PRINT_MACRO(BOOST_NO_0X_HDR_CODECVT);
-   PRINT_MACRO(BOOST_NO_0X_HDR_CONCEPTS);
-   PRINT_MACRO(BOOST_NO_0X_HDR_CONDITION_VARIABLE);
-   PRINT_MACRO(BOOST_NO_0X_HDR_CONTAINER_CONCEPTS);
-   PRINT_MACRO(BOOST_NO_0X_HDR_FORWARD_LIST);
-   PRINT_MACRO(BOOST_NO_0X_HDR_FUTURE);
-   PRINT_MACRO(BOOST_NO_0X_HDR_INITIALIZER_LIST);
-   PRINT_MACRO(BOOST_NO_0X_HDR_ITERATOR_CONCEPTS);
-   PRINT_MACRO(BOOST_NO_0X_HDR_MEMORY_CONCEPTS);
-   PRINT_MACRO(BOOST_NO_0X_HDR_MUTEX);
-   PRINT_MACRO(BOOST_NO_0X_HDR_RANDOM);
-   PRINT_MACRO(BOOST_NO_0X_HDR_RATIO);
-   PRINT_MACRO(BOOST_NO_0X_HDR_REGEX);
-   PRINT_MACRO(BOOST_NO_0X_HDR_SYSTEM_ERROR);
-   PRINT_MACRO(BOOST_NO_0X_HDR_THREAD);
-   PRINT_MACRO(BOOST_NO_0X_HDR_TUPLE);
-   PRINT_MACRO(BOOST_NO_0X_HDR_TYPE_TRAITS);
-   PRINT_MACRO(BOOST_NO_0X_HDR_UNORDERED_MAP);
-   PRINT_MACRO(BOOST_NO_0X_HDR_UNORDERED_SET);
    PRINT_MACRO(BOOST_NO_ADL_BARRIER);
    PRINT_MACRO(BOOST_NO_ARGUMENT_DEPENDENT_LOOKUP);
    PRINT_MACRO(BOOST_NO_ARRAY_TYPE_SPECIALIZATIONS);
-   PRINT_MACRO(BOOST_NO_AUTO_DECLARATIONS);
-   PRINT_MACRO(BOOST_NO_AUTO_MULTIDECLARATIONS);
    PRINT_MACRO(BOOST_NO_AUTO_PTR);
-   PRINT_MACRO(BOOST_NO_CHAR16_T);
-   PRINT_MACRO(BOOST_NO_CHAR32_T);
-   PRINT_MACRO(BOOST_NO_CONCEPTS);
-   PRINT_MACRO(BOOST_NO_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_COMPLETE_VALUE_INITIALIZATION);
    PRINT_MACRO(BOOST_NO_CTYPE_FUNCTIONS);
    PRINT_MACRO(BOOST_NO_CV_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_CV_VOID_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_CWCHAR);
    PRINT_MACRO(BOOST_NO_CWCTYPE);
-   PRINT_MACRO(BOOST_NO_DECLTYPE);
-   PRINT_MACRO(BOOST_NO_DEFAULTED_FUNCTIONS);
-   PRINT_MACRO(BOOST_NO_DELETED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX03);
+   PRINT_MACRO(BOOST_NO_CXX11);
+   PRINT_MACRO(BOOST_NO_CXX11_ADDRESSOF);
+   PRINT_MACRO(BOOST_NO_CXX11_ALIGNAS);
+   PRINT_MACRO(BOOST_NO_CXX11_ALLOCATOR);
+   PRINT_MACRO(BOOST_NO_CXX11_ATOMIC_SMART_PTR);
+   PRINT_MACRO(BOOST_NO_CXX11_AUTO_DECLARATIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_AUTO_MULTIDECLARATIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_CHAR16_T);
+   PRINT_MACRO(BOOST_NO_CXX11_CHAR32_T);
+   PRINT_MACRO(BOOST_NO_CXX11_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_CXX11_DECLTYPE);
+   PRINT_MACRO(BOOST_NO_CXX11_DECLTYPE_N3276);
+   PRINT_MACRO(BOOST_NO_CXX11_DEFAULTED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_DEFAULTED_MOVES);
+   PRINT_MACRO(BOOST_NO_CXX11_DELETED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_EXPLICIT_CONVERSION_OPERATORS);
+   PRINT_MACRO(BOOST_NO_CXX11_EXTERN_TEMPLATE);
+   PRINT_MACRO(BOOST_NO_CXX11_FINAL);
+   PRINT_MACRO(BOOST_NO_CXX11_FIXED_LENGTH_VARIADIC_TEMPLATE_EXPANSION_PACKS);
+   PRINT_MACRO(BOOST_NO_CXX11_FUNCTION_TEMPLATE_DEFAULT_ARGS);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_ARRAY);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_ATOMIC);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CHRONO);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CODECVT);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_CONDITION_VARIABLE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_EXCEPTION);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FORWARD_LIST);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FUNCTIONAL);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_FUTURE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_INITIALIZER_LIST);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_MUTEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_RANDOM);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_RATIO);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_REGEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_SYSTEM_ERROR);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_THREAD);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TUPLE);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TYPEINDEX);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_TYPE_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_UNORDERED_MAP);
+   PRINT_MACRO(BOOST_NO_CXX11_HDR_UNORDERED_SET);
+   PRINT_MACRO(BOOST_NO_CXX11_INLINE_NAMESPACES);
+   PRINT_MACRO(BOOST_NO_CXX11_LAMBDAS);
+   PRINT_MACRO(BOOST_NO_CXX11_LOCAL_CLASS_TEMPLATE_PARAMETERS);
+   PRINT_MACRO(BOOST_NO_CXX11_NOEXCEPT);
+   PRINT_MACRO(BOOST_NO_CXX11_NON_PUBLIC_DEFAULTED_FUNCTIONS);
+   PRINT_MACRO(BOOST_NO_CXX11_NULLPTR);
+   PRINT_MACRO(BOOST_NO_CXX11_NUMERIC_LIMITS);
+   PRINT_MACRO(BOOST_NO_CXX11_OVERRIDE);
+   PRINT_MACRO(BOOST_NO_CXX11_POINTER_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX11_RANGE_BASED_FOR);
+   PRINT_MACRO(BOOST_NO_CXX11_RAW_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_REF_QUALIFIERS);
+   PRINT_MACRO(BOOST_NO_CXX11_RVALUE_REFERENCES);
+   PRINT_MACRO(BOOST_NO_CXX11_SCOPED_ENUMS);
+   PRINT_MACRO(BOOST_NO_CXX11_SFINAE_EXPR);
+   PRINT_MACRO(BOOST_NO_CXX11_SMART_PTR);
+   PRINT_MACRO(BOOST_NO_CXX11_STATIC_ASSERT);
+   PRINT_MACRO(BOOST_NO_CXX11_STD_ALIGN);
+   PRINT_MACRO(BOOST_NO_CXX11_TEMPLATE_ALIASES);
+   PRINT_MACRO(BOOST_NO_CXX11_THREAD_LOCAL);
+   PRINT_MACRO(BOOST_NO_CXX11_TRAILING_RESULT_TYPES);
+   PRINT_MACRO(BOOST_NO_CXX11_UNICODE_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX);
+   PRINT_MACRO(BOOST_NO_CXX11_UNRESTRICTED_UNION);
+   PRINT_MACRO(BOOST_NO_CXX11_USER_DEFINED_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX11_VARIADIC_MACROS);
+   PRINT_MACRO(BOOST_NO_CXX11_VARIADIC_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_CXX14);
+   PRINT_MACRO(BOOST_NO_CXX14_AGGREGATE_NSDMI);
+   PRINT_MACRO(BOOST_NO_CXX14_BINARY_LITERALS);
+   PRINT_MACRO(BOOST_NO_CXX14_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_CXX14_DECLTYPE_AUTO);
+   PRINT_MACRO(BOOST_NO_CXX14_DIGIT_SEPARATORS);
+   PRINT_MACRO(BOOST_NO_CXX14_GENERIC_LAMBDAS);
+   PRINT_MACRO(BOOST_NO_CXX14_HDR_SHARED_MUTEX);
+   PRINT_MACRO(BOOST_NO_CXX14_INITIALIZED_LAMBDA_CAPTURES);
+   PRINT_MACRO(BOOST_NO_CXX14_RETURN_TYPE_DEDUCTION);
+   PRINT_MACRO(BOOST_NO_CXX14_STD_EXCHANGE);
+   PRINT_MACRO(BOOST_NO_CXX14_VARIABLE_TEMPLATES);
+   PRINT_MACRO(BOOST_NO_CXX17);
+   PRINT_MACRO(BOOST_NO_CXX17_FOLD_EXPRESSIONS);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_ANY);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_CHARCONV);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_EXECUTION);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_FILESYSTEM);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_MEMORY_RESOURCE);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_OPTIONAL);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_STRING_VIEW);
+   PRINT_MACRO(BOOST_NO_CXX17_HDR_VARIANT);
+   PRINT_MACRO(BOOST_NO_CXX17_IF_CONSTEXPR);
+   PRINT_MACRO(BOOST_NO_CXX17_INLINE_VARIABLES);
+   PRINT_MACRO(BOOST_NO_CXX17_ITERATOR_TRAITS);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_APPLY);
+   PRINT_MACRO(BOOST_NO_CXX17_STD_INVOKE);
+   PRINT_MACRO(BOOST_NO_CXX17_STRUCTURED_BINDINGS);
+   PRINT_MACRO(BOOST_NO_CXX98_BINDERS);
+   PRINT_MACRO(BOOST_NO_CXX98_FUNCTION_BASE);
+   PRINT_MACRO(BOOST_NO_CXX98_RANDOM_SHUFFLE);
    PRINT_MACRO(BOOST_NO_DEPENDENT_NESTED_DERIVATIONS);
    PRINT_MACRO(BOOST_NO_DEPENDENT_TYPES_IN_TEMPLATE_VALUE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_EXCEPTIONS);
    PRINT_MACRO(BOOST_NO_EXCEPTION_STD_NAMESPACE);
-   PRINT_MACRO(BOOST_NO_EXPLICIT_CONVERSION_OPERATORS);
    PRINT_MACRO(BOOST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS);
-   PRINT_MACRO(BOOST_NO_EXTERN_TEMPLATE);
+   PRINT_MACRO(BOOST_NO_FENV_H);
    PRINT_MACRO(BOOST_NO_FUNCTION_TEMPLATE_ORDERING);
    PRINT_MACRO(BOOST_NO_FUNCTION_TYPE_SPECIALIZATIONS);
    PRINT_MACRO(BOOST_NO_INCLASS_MEMBER_INITIALIZATION);
-   PRINT_MACRO(BOOST_NO_INITIALIZER_LISTS);
    PRINT_MACRO(BOOST_NO_INTEGRAL_INT64_T);
    PRINT_MACRO(BOOST_NO_INTRINSIC_WCHAR_T);
    PRINT_MACRO(BOOST_NO_IOSFWD);
    PRINT_MACRO(BOOST_NO_IOSTREAM);
    PRINT_MACRO(BOOST_NO_IS_ABSTRACT);
-   PRINT_MACRO(BOOST_NO_LAMBDAS);
    PRINT_MACRO(BOOST_NO_LIMITS);
    PRINT_MACRO(BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS);
    PRINT_MACRO(BOOST_NO_LONG_LONG);
@@ -1020,18 +1208,15 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_MEMBER_TEMPLATE_KEYWORD);
    PRINT_MACRO(BOOST_NO_MS_INT64_NUMERIC_LIMITS);
    PRINT_MACRO(BOOST_NO_NESTED_FRIENDSHIP);
-   PRINT_MACRO(BOOST_NO_NULLPTR);
    PRINT_MACRO(BOOST_NO_OPERATORS_IN_NAMESPACE);
    PRINT_MACRO(BOOST_NO_PARTIAL_SPECIALIZATION_IMPLICIT_DEFAULT_ARGS);
    PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_CONST);
    PRINT_MACRO(BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS);
    PRINT_MACRO(BOOST_NO_PRIVATE_IN_AGGREGATE);
-   PRINT_MACRO(BOOST_NO_RAW_LITERALS);
+   PRINT_MACRO(BOOST_NO_RESTRICT_REFERENCES);
    PRINT_MACRO(BOOST_NO_RTTI);
-   PRINT_MACRO(BOOST_NO_RVALUE_REFERENCES);
-   PRINT_MACRO(BOOST_NO_SCOPED_ENUMS);
    PRINT_MACRO(BOOST_NO_SFINAE);
-   PRINT_MACRO(BOOST_NO_STATIC_ASSERT);
+   PRINT_MACRO(BOOST_NO_SFINAE_EXPR);
    PRINT_MACRO(BOOST_NO_STDC_NAMESPACE);
    PRINT_MACRO(BOOST_NO_STD_ALLOCATOR);
    PRINT_MACRO(BOOST_NO_STD_DISTANCE);
@@ -1042,7 +1227,6 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_STD_MIN_MAX);
    PRINT_MACRO(BOOST_NO_STD_OUTPUT_ITERATOR_ASSIGN);
    PRINT_MACRO(BOOST_NO_STD_TYPEINFO);
-   PRINT_MACRO(BOOST_NO_STD_UNORDERED);
    PRINT_MACRO(BOOST_NO_STD_USE_FACET);
    PRINT_MACRO(BOOST_NO_STD_WSTREAMBUF);
    PRINT_MACRO(BOOST_NO_STD_WSTRING);
@@ -1050,35 +1234,243 @@ void print_boost_macros()
    PRINT_MACRO(BOOST_NO_SWPRINTF);
    PRINT_MACRO(BOOST_NO_TEMPLATED_IOSTREAMS);
    PRINT_MACRO(BOOST_NO_TEMPLATED_ITERATOR_CONSTRUCTORS);
-   PRINT_MACRO(BOOST_NO_TEMPLATE_ALIASES);
    PRINT_MACRO(BOOST_NO_TEMPLATE_PARTIAL_SPECIALIZATION);
    PRINT_MACRO(BOOST_NO_TEMPLATE_TEMPLATES);
    PRINT_MACRO(BOOST_NO_TWO_PHASE_NAME_LOOKUP);
    PRINT_MACRO(BOOST_NO_TYPEID);
    PRINT_MACRO(BOOST_NO_TYPENAME_WITH_CTOR);
-   PRINT_MACRO(BOOST_NO_UNICODE_LITERALS);
    PRINT_MACRO(BOOST_NO_UNREACHABLE_RETURN_DETECTION);
    PRINT_MACRO(BOOST_NO_USING_DECLARATION_OVERLOADS_FROM_TYPENAME_BASE);
    PRINT_MACRO(BOOST_NO_USING_TEMPLATE);
-   PRINT_MACRO(BOOST_NO_VARIADIC_TEMPLATES);
    PRINT_MACRO(BOOST_NO_VOID_RETURNS);
-
-
-
-
-
-
-
-
-
-
-
    // END GENERATED BLOCK
 
+   PRINT_MACRO(BOOST_CXX_VERSION);
    PRINT_MACRO(BOOST_INTEL);
    PRINT_MACRO(BOOST_MSVC);
+   PRINT_MACRO(BOOST_GCC);
+   PRINT_MACRO(BOOST_LIBSTDCXX_VERSION);
    PRINT_MACRO(BOOST_STD_EXTENSION_NAMESPACE);
    PRINT_MACRO(BOOST_UNREACHABLE_RETURN(0));
+   PRINT_MACRO(BOOST_CONSTEXPR);
+   PRINT_MACRO(BOOST_CONSTEXPR_OR_CONST);
+   PRINT_MACRO(BOOST_STATIC_CONSTEXPR);
+   PRINT_MACRO(BOOST_NOEXCEPT);
+   PRINT_MACRO(BOOST_FORCEINLINE);
+   PRINT_MACRO(BOOST_NOINLINE);
+   PRINT_MACRO(BOOST_FALLTHROUGH);
+   PRINT_MACRO(BOOST_MAY_ALIAS);
+   PRINT_MACRO(BOOST_NO_MAY_ALIAS);
+   PRINT_MACRO(BOOST_ATTRIBUTE_NO_UNIQUE_ADDRESS);
+   PRINT_MACRO(BOOST_ATTRIBUTE_UNUSED);
+   PRINT_MACRO(BOOST_UNLIKELY);
+   PRINT_MACRO(BOOST_NORETURN);
+}
+
+#ifdef __has_include
+#if __has_include(<version>)
+#  include <version>
+#endif
+#endif
+
+void print_sd6_macros()
+{
+    // http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2017/p0096r5.html
+
+    // Library macros are only really available if we have <version> :
+
+    PRINT_MACRO(__cpp_lib_addressof_constexpr);
+    PRINT_MACRO(__cpp_lib_allocator_traits_is_always_equal);
+    PRINT_MACRO(__cpp_lib_any);
+    PRINT_MACRO(__cpp_lib_apply);
+    PRINT_MACRO(__cpp_lib_array_constexpr);
+    PRINT_MACRO(__cpp_lib_as_const);
+    PRINT_MACRO(__cpp_lib_assume_aligned);
+    PRINT_MACRO(__cpp_lib_atomic_flag_test);
+    PRINT_MACRO(__cpp_lib_atomic_float);
+    PRINT_MACRO(__cpp_lib_atomic_is_always_lock_free);
+    PRINT_MACRO(__cpp_lib_atomic_lock_free_type_aliases);
+    PRINT_MACRO(__cpp_lib_atomic_ref);
+    PRINT_MACRO(__cpp_lib_atomic_shared_ptr);
+    PRINT_MACRO(__cpp_lib_atomic_value_initialization);
+    PRINT_MACRO(__cpp_lib_atomic_wait);
+    PRINT_MACRO(__cpp_lib_barrier);
+    PRINT_MACRO(__cpp_lib_bind_front);
+    PRINT_MACRO(__cpp_lib_bit_cast);
+    PRINT_MACRO(__cpp_lib_bitops);
+    PRINT_MACRO(__cpp_lib_bool_constant);
+    PRINT_MACRO(__cpp_lib_bounded_array_traits);
+    PRINT_MACRO(__cpp_lib_boyer_moore_searcher);
+    PRINT_MACRO(__cpp_lib_byte);
+    PRINT_MACRO(__cpp_lib_char8_t);
+    PRINT_MACRO(__cpp_lib_chrono);
+    PRINT_MACRO(__cpp_lib_chrono_udls);
+    PRINT_MACRO(__cpp_lib_clamp);
+    PRINT_MACRO(__cpp_lib_complex_udls);
+    PRINT_MACRO(__cpp_lib_concepts);
+    PRINT_MACRO(__cpp_lib_constexpr_algorithms);
+    PRINT_MACRO(__cpp_lib_constexpr_complex);
+    PRINT_MACRO(__cpp_lib_constexpr_dynamic_alloc);
+    PRINT_MACRO(__cpp_lib_constexpr_functional);
+    PRINT_MACRO(__cpp_lib_constexpr_iterator);
+    PRINT_MACRO(__cpp_lib_constexpr_memory);
+    PRINT_MACRO(__cpp_lib_constexpr_numeric);
+    PRINT_MACRO(__cpp_lib_constexpr_string);
+    PRINT_MACRO(__cpp_lib_constexpr_string_view);
+    PRINT_MACRO(__cpp_lib_constexpr_tuple);
+    PRINT_MACRO(__cpp_lib_constexpr_utility);
+    PRINT_MACRO(__cpp_lib_constexpr_vector);
+    PRINT_MACRO(__cpp_lib_coroutine);
+    PRINT_MACRO(__cpp_lib_destroying_delete);
+    PRINT_MACRO(__cpp_lib_enable_shared_from_this);
+    PRINT_MACRO(__cpp_lib_endian);
+    PRINT_MACRO(__cpp_lib_erase_if);
+    PRINT_MACRO(__cpp_lib_exchange_function);
+    PRINT_MACRO(__cpp_lib_execution);
+    PRINT_MACRO(__cpp_lib_filesystem);
+    PRINT_MACRO(__cpp_lib_format);
+    PRINT_MACRO(__cpp_lib_gcd_lcm);
+    PRINT_MACRO(__cpp_lib_generic_associative_lookup);
+    PRINT_MACRO(__cpp_lib_generic_unordered_lookup);
+    PRINT_MACRO(__cpp_lib_hardware_interference_size);
+    PRINT_MACRO(__cpp_lib_has_unique_object_representations);
+    PRINT_MACRO(__cpp_lib_hypot);
+    PRINT_MACRO(__cpp_lib_incomplete_container_elements);
+    PRINT_MACRO(__cpp_lib_int_pow2);
+    PRINT_MACRO(__cpp_lib_integer_comparison_functions);
+    PRINT_MACRO(__cpp_lib_integer_sequence);
+    PRINT_MACRO(__cpp_lib_integral_constant_callable);
+    PRINT_MACRO(__cpp_lib_interpolate);
+    PRINT_MACRO(__cpp_lib_invoke);
+    PRINT_MACRO(__cpp_lib_is_aggregate);
+    PRINT_MACRO(__cpp_lib_is_constant_evaluated);
+    PRINT_MACRO(__cpp_lib_is_final);
+    PRINT_MACRO(__cpp_lib_is_invocable);
+    PRINT_MACRO(__cpp_lib_is_layout_compatible);
+    PRINT_MACRO(__cpp_lib_is_nothrow_convertible);
+    PRINT_MACRO(__cpp_lib_is_null_pointer);
+    PRINT_MACRO(__cpp_lib_is_pointer_interconvertible);
+    PRINT_MACRO(__cpp_lib_is_swappable);
+    PRINT_MACRO(__cpp_lib_jthread);
+    PRINT_MACRO(__cpp_lib_latch);
+    PRINT_MACRO(__cpp_lib_launder);
+    PRINT_MACRO(__cpp_lib_list_remove_return_type);
+    PRINT_MACRO(__cpp_lib_logical_traits);
+    PRINT_MACRO(__cpp_lib_make_from_tuple);
+    PRINT_MACRO(__cpp_lib_make_reverse_iterator);
+    PRINT_MACRO(__cpp_lib_make_unique);
+    PRINT_MACRO(__cpp_lib_map_try_emplace);
+    PRINT_MACRO(__cpp_lib_math_constants);
+    PRINT_MACRO(__cpp_lib_math_special_functions);
+    PRINT_MACRO(__cpp_lib_memory_resource);
+    PRINT_MACRO(__cpp_lib_node_extract);
+    PRINT_MACRO(__cpp_lib_nonmember_container_access);
+    PRINT_MACRO(__cpp_lib_not_fn);
+    PRINT_MACRO(__cpp_lib_null_iterators);
+    PRINT_MACRO(__cpp_lib_optional);
+    PRINT_MACRO(__cpp_lib_parallel_algorithm);
+    PRINT_MACRO(__cpp_lib_polymorphic_allocator);
+    PRINT_MACRO(__cpp_lib_quoted_string_io);
+    PRINT_MACRO(__cpp_lib_ranges);
+    PRINT_MACRO(__cpp_lib_raw_memory_algorithms);
+    PRINT_MACRO(__cpp_lib_remove_cvref);
+    PRINT_MACRO(__cpp_lib_result_of_sfinae);
+    PRINT_MACRO(__cpp_lib_robust_nonmodifying_seq_ops);
+    PRINT_MACRO(__cpp_lib_sample);
+    PRINT_MACRO(__cpp_lib_scoped_lock);
+    PRINT_MACRO(__cpp_lib_semaphore);
+    PRINT_MACRO(__cpp_lib_shared_mutex);
+    PRINT_MACRO(__cpp_lib_shared_ptr_arrays);
+    PRINT_MACRO(__cpp_lib_shared_ptr_weak_type);
+    PRINT_MACRO(__cpp_lib_shared_timed_mutex);
+    PRINT_MACRO(__cpp_lib_shift);
+    PRINT_MACRO(__cpp_lib_smart_ptr_for_overwrite);
+    PRINT_MACRO(__cpp_lib_source_location);
+    PRINT_MACRO(__cpp_lib_span);
+    PRINT_MACRO(__cpp_lib_ssize);
+    PRINT_MACRO(__cpp_lib_starts_ends_with);
+    PRINT_MACRO(__cpp_lib_string_udls);
+    PRINT_MACRO(__cpp_lib_string_view);
+    PRINT_MACRO(__cpp_lib_syncbuf);
+    PRINT_MACRO(__cpp_lib_three_way_comparison);
+    PRINT_MACRO(__cpp_lib_to_address);
+    PRINT_MACRO(__cpp_lib_to_array);
+    PRINT_MACRO(__cpp_lib_to_chars);
+    PRINT_MACRO(__cpp_lib_transformation_trait_aliases);
+    PRINT_MACRO(__cpp_lib_transparent_operators);
+    PRINT_MACRO(__cpp_lib_tuple_element_t);
+    PRINT_MACRO(__cpp_lib_tuples_by_type);
+    PRINT_MACRO(__cpp_lib_type_identity);
+    PRINT_MACRO(__cpp_lib_type_trait_variable_templates);
+    PRINT_MACRO(__cpp_lib_uncaught_exceptions);
+    PRINT_MACRO(__cpp_lib_unordered_map_try_emplace);
+    PRINT_MACRO(__cpp_lib_unwrap_ref);
+    PRINT_MACRO(__cpp_lib_variant);
+    PRINT_MACRO(__cpp_lib_void_t);
+
+    // C++20:
+    PRINT_MACRO(__cpp_aggregate_paren_init);
+    PRINT_MACRO(__cpp_char8_t);
+    PRINT_MACRO(__cpp_char8_type);
+    PRINT_MACRO(__cpp_conditional_explicit);
+    PRINT_MACRO(__cpp_coroutines);
+    PRINT_MACRO(__cpp_impl_destroying_delete);
+    PRINT_MACRO(__cpp_impl_three_way_comparison);
+    PRINT_MACRO(__cpp_nontype_template_parameter_class);
+
+    // C++17:
+    PRINT_MACRO(__cpp_hex_float);
+    PRINT_MACRO(__cpp_inline_variables);
+    PRINT_MACRO(__cpp_aligned_new);
+    PRINT_MACRO(__cpp_guaranteed_copy_elision);
+    PRINT_MACRO(__cpp_noexcept_function_type);
+    PRINT_MACRO(__cpp_fold_expressions);
+    PRINT_MACRO(__cpp_capture_star_this);
+    PRINT_MACRO(__cpp_constexpr);
+    PRINT_MACRO(__cpp_if_constexpr);
+    PRINT_MACRO(__cpp_range_based_for);
+    PRINT_MACRO(__cpp_static_assert);
+    PRINT_MACRO(__cpp_deduction_guides);
+    PRINT_MACRO(__cpp_nontype_template_parameter_auto);
+    PRINT_MACRO(__cpp_namespace_attributes);
+    PRINT_MACRO(__cpp_enumerator_attributes);
+    PRINT_MACRO(__cpp_inheriting_constructors);
+    PRINT_MACRO(__cpp_variadic_using);
+    PRINT_MACRO(__cpp_structured_bindings);
+    PRINT_MACRO(__cpp_aggregate_bases);
+    PRINT_MACRO(__cpp_nontype_template_args);
+    PRINT_MACRO(__cpp_template_template_args);
+
+    // C++14:
+    PRINT_MACRO(__cpp_binary_literals);
+    PRINT_MACRO(__cpp_init_captures);
+    PRINT_MACRO(__cpp_generic_lambdas);
+    PRINT_MACRO(__cpp_sized_deallocation);
+    PRINT_MACRO(__cpp_decltype_auto);
+    PRINT_MACRO(__cpp_return_type_deduction);
+    PRINT_MACRO(__cpp_aggregate_nsdmi);
+    PRINT_MACRO(__cpp_variable_templates);
+
+    // C++11:
+    PRINT_MACRO(__cpp_unicode_characters);
+    PRINT_MACRO(__cpp_raw_strings);
+    PRINT_MACRO(__cpp_unicode_literals);
+    PRINT_MACRO(__cpp_user_defined_literals);
+    PRINT_MACRO(__cpp_threadsafe_static_init);
+    PRINT_MACRO(__cpp_lambdas);
+    PRINT_MACRO(__cpp_decltype);
+    PRINT_MACRO(__cpp_attributes);
+    PRINT_MACRO(__cpp_rvalue_references);
+    PRINT_MACRO(__cpp_variadic_templates);
+    PRINT_MACRO(__cpp_initializer_lists);
+    PRINT_MACRO(__cpp_delegating_constructors);
+    PRINT_MACRO(__cpp_nsdmi);
+    PRINT_MACRO(__cpp_ref_qualifiers);
+    PRINT_MACRO(__cpp_alias_templates);
+
+    // C++98:
+    PRINT_MACRO(__cpp_rtti);
+    PRINT_MACRO(__cpp_exceptions);
 }
 
 void print_separator()
@@ -1098,6 +1490,8 @@ int main()
   print_platform_macros();
   print_separator();
   print_boost_macros();
+  print_separator();
+  print_sd6_macros();
 
   return 0;
 }
