@@ -1,6 +1,6 @@
 //////////////////////////////////////////////////////////////////////////////
 //
-// (C) Copyright Ion Gaztanaga 2006-2007. Distributed under the Boost
+// (C) Copyright Ion Gaztanaga 2006-2012. Distributed under the Boost
 // Software License, Version 1.0. (See accompanying file
 // LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 //
@@ -20,12 +20,12 @@ int main ()
    try{
       //Open a message queue.
       message_queue mq
-         (open_only        //only create
+         (open_only        //only open
          ,"message_queue"  //name
          );
 
       unsigned int priority;
-      std::size_t recvd_size;
+      message_queue::size_type recvd_size;
 
       //Receive 100 numbers
       for(int i = 0; i < 100; ++i){
