@@ -35,8 +35,8 @@ BOOST_MATH_DECLARE_DISTRIBUTIONS(double, test_policy)
 #endif
 
 #if !defined(TEST_GROUP_1) && !defined(TEST_GROUP_2) && !defined(TEST_GROUP_3) \
-   && !defined(TEST_GROUP_4) && !defined(TEST_GROUP_5) && !defined(TEST_GROUP_6) \
-   && !defined(TEST_GROUP_7) && !defined(TEST_GROUP_8) && !defined(TEST_GROUP_9)
+   && !defined(TEST_GROUP_4) && !defined(TEST_GROUP_5) && !defined(TEST_GROUP_6) && !defined(TEST_GROUP_7) && !defined(TEST_GROUP_8) && !defined(TEST_GROUP_9) \
+   && !defined(TEST_GROUP_10) && !defined(TEST_GROUP_11) && !defined(TEST_GROUP_12) && !defined(TEST_GROUP_13) && !defined(TEST_GROUP_14) && !defined(TEST_GROUP_15)
 #  define TEST_GROUP_1
 #  define TEST_GROUP_2
 #  define TEST_GROUP_3
@@ -46,6 +46,12 @@ BOOST_MATH_DECLARE_DISTRIBUTIONS(double, test_policy)
 #  define TEST_GROUP_7
 #  define TEST_GROUP_8
 #  define TEST_GROUP_9
+#  define TEST_GROUP_10
+#  define TEST_GROUP_11
+#  define TEST_GROUP_12
+#  define TEST_GROUP_13
+#  define TEST_GROUP_14
+#  define TEST_GROUP_15
 #endif
 
 template <class RealType>
@@ -54,6 +60,11 @@ void instantiate(RealType)
    using namespace boost;
    using namespace boost::math;
    using namespace boost::math::concepts;
+
+   long l;
+#ifdef BOOST_HAS_LONG_LONG
+   boost::long_long_type ll;
+#endif
 #ifdef TEST_GROUP_1
    function_requires<DistributionConcept<arcsine_distribution<RealType> > >();
    function_requires<DistributionConcept<bernoulli_distribution<RealType> > >();
@@ -71,6 +82,7 @@ void instantiate(RealType)
    function_requires<DistributionConcept<inverse_chi_squared_distribution<RealType> > >();
    function_requires<DistributionConcept<inverse_gamma_distribution<RealType> > >();
    function_requires<DistributionConcept<inverse_gaussian_distribution<RealType> > >();
+   function_requires<DistributionConcept<kolmogorov_smirnov_distribution<RealType> > >();
    function_requires<DistributionConcept<laplace_distribution<RealType> > >();
    function_requires<DistributionConcept<logistic_distribution<RealType> > >();
    function_requires<DistributionConcept<lognormal_distribution<RealType> > >();
@@ -106,6 +118,7 @@ void instantiate(RealType)
    function_requires<DistributionConcept<inverse_chi_squared_distribution<RealType, test_policy> > >();
    function_requires<DistributionConcept<inverse_gamma_distribution<RealType, test_policy> > >();
    function_requires<DistributionConcept<inverse_gaussian_distribution<RealType, test_policy> > >();
+   function_requires<DistributionConcept<kolmogorov_smirnov_distribution<RealType, test_policy> > >();
    function_requires<DistributionConcept<laplace_distribution<RealType, test_policy> > >();
    function_requires<DistributionConcept<logistic_distribution<RealType, test_policy> > >();
    function_requires<DistributionConcept<lognormal_distribution<RealType, test_policy> > >();
@@ -159,7 +172,9 @@ void instantiate(RealType)
    function_requires<DistributionConcept<dist_test::hypergeometric > >();
 #endif
 #endif
-   int i;
+   int i = 1;
+   // Deal with unused variable warnings:
+   (void)i;
    RealType v1(0.5), v2(0.5), v3(0.5);
    boost::detail::dummy_constructor dc;
    boost::output_iterator_archetype<RealType> oi(dc);
@@ -219,9 +234,12 @@ void instantiate(RealType)
    boost::math::cbrt(v1);
    boost::math::sqrt1pm1(v1);
    boost::math::powm1(v1, v2);
+#endif
+#ifdef TEST_GROUP_5
    boost::math::legendre_p(1, v1);
    boost::math::legendre_p(1, 0, v1);
    boost::math::legendre_q(1, v1);
+   boost::math::legendre_p_prime(1, v1);
    boost::math::legendre_next(2, v1, v2, v3);
    boost::math::legendre_next(2, 2, v1, v2, v3);
    boost::math::laguerre(1, v1);
@@ -231,6 +249,11 @@ void instantiate(RealType)
    boost::math::laguerre_next(2, 1, v1, v2, v3);
    boost::math::hermite(1, v1);
    boost::math::hermite_next(2, v1, v2, v3);
+   boost::math::chebyshev_next(v1, v2, v3);
+   boost::math::chebyshev_t(1, v1);
+   boost::math::chebyshev_u(1, v1);
+   boost::math::chebyshev_t_prime(1, v1);
+   boost::math::chebyshev_clenshaw_recurrence(&v1, 0, v2);
    boost::math::spherical_harmonic_r(2, 1, v1, v2);
    boost::math::spherical_harmonic_i(2, 1, v1, v2);
    boost::math::ellint_1(v1);
@@ -261,6 +284,18 @@ void instantiate(RealType)
    boost::math::jacobi_sc(v1, v2);
    boost::math::jacobi_sd(v1, v2);
    boost::math::jacobi_sn(v1, v2);
+   boost::math::jacobi_theta1(v1, v2);
+   boost::math::jacobi_theta1tau(v1, v2);
+   boost::math::jacobi_theta2(v1, v2);
+   boost::math::jacobi_theta2tau(v1, v2);
+   boost::math::jacobi_theta3(v1, v2);
+   boost::math::jacobi_theta3tau(v1, v2);
+   boost::math::jacobi_theta3m1(v1, v2);
+   boost::math::jacobi_theta3m1tau(v1, v2);
+   boost::math::jacobi_theta4(v1, v2);
+   boost::math::jacobi_theta4tau(v1, v2);
+   boost::math::jacobi_theta4m1(v1, v2);
+   boost::math::jacobi_theta4m1tau(v1, v2);
    boost::math::hypot(v1, v2);
    boost::math::sinc_pi(v1);
    boost::math::sinhc_pi(v1);
@@ -269,6 +304,8 @@ void instantiate(RealType)
    boost::math::atanh(v1);
    boost::math::sin_pi(v1);
    boost::math::cos_pi(v1);
+#endif
+#ifdef TEST_GROUP_6
    boost::math::cyl_neumann(v1, v2);
    boost::math::cyl_neumann(i, v2);
    boost::math::cyl_bessel_j(v1, v2);
@@ -297,6 +334,9 @@ void instantiate(RealType)
    boost::math::cyl_bessel_j_zero(v1, i, i, oi);
    boost::math::cyl_neumann_zero(v1, i);
    boost::math::cyl_neumann_zero(v1, i, i, oi);
+   boost::math::lambert_w0(v1);
+   boost::math::lambert_wm1(v1);
+   boost::math::lambert_w0_prime(v1);
 #ifdef TEST_COMPLEX
    boost::math::cyl_hankel_1(v1, v2);
    boost::math::cyl_hankel_1(i, v2);
@@ -307,6 +347,8 @@ void instantiate(RealType)
    boost::math::sph_hankel_2(v1, v2);
    boost::math::sph_hankel_2(i, v2);
 #endif
+#endif
+#ifdef TEST_GROUP_7
    boost::math::airy_ai(v1);
    boost::math::airy_bi(v1);
    boost::math::airy_ai_prime(v1);
@@ -317,6 +359,16 @@ void instantiate(RealType)
    boost::math::airy_ai_zero<RealType>(i, i, oi);
    boost::math::airy_bi_zero<RealType>(i, i, oi);
 
+   boost::math::hypergeometric_1F0(v1, v2);
+   boost::math::hypergeometric_0F1(v1, v2);
+   boost::math::hypergeometric_2F0(v1, v2, v3);
+#if !defined(BOOST_NO_CXX11_AUTO_DECLARATIONS) && !defined(BOOST_NO_CXX11_LAMBDAS) && !defined(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX) && !defined(BOOST_NO_CXX11_HDR_TUPLE)
+   boost::math::hypergeometric_1F1(v1, v2, v3);
+#ifndef BOOST_NO_CXX11_HDR_INITIALIZER_LIST
+   boost::math::hypergeometric_pFq({ v1 }, { v2 }, v3);
+#endif
+#endif
+
    boost::math::expint(v1);
    boost::math::expint(i);
    boost::math::expint(i, v2);
@@ -332,12 +384,10 @@ void instantiate(RealType)
    boost::math::lround(v1);
    boost::math::modf(v1, &v1);
    boost::math::modf(v1, &i);
-   long l;
    boost::math::modf(v1, &l);
 #ifdef BOOST_HAS_LONG_LONG
    boost::math::lltrunc(v1);
    boost::math::llround(v1);
-   boost::long_long_type ll;
    boost::math::modf(v1, &ll);
 #endif
    boost::math::pow<2>(v1);
@@ -345,6 +395,9 @@ void instantiate(RealType)
    boost::math::float_next(v1);
    boost::math::float_prior(v1);
    boost::math::float_distance(v1, v1);
+   boost::math::ulp(v1);
+   boost::math::relative_difference(v1, v2);
+   boost::math::epsilon_difference(v1, v2);
 
    boost::math::unchecked_bernoulli_b2n<RealType>(i);
    boost::math::bernoulli_b2n<RealType>(i);
@@ -353,7 +406,7 @@ void instantiate(RealType)
    boost::math::tangent_t2n<RealType>(i, i, &v1);
 
 #endif
-#ifdef TEST_GROUP_9
+#ifdef TEST_GROUP_12
    //
    // Over again, but arguments may be expression templates:
    //
@@ -411,8 +464,11 @@ void instantiate(RealType)
    boost::math::cbrt(v1 * 1);
    boost::math::sqrt1pm1(v1 * 1);
    boost::math::powm1(v1 * 1, v2 + 0);
+#endif
+#ifdef TEST_GROUP_13
    boost::math::legendre_p(1, v1 * 1);
    boost::math::legendre_p(1, 0, v1 * 1);
+   boost::math::legendre_p_prime(1, v1 * 1);
    boost::math::legendre_q(1, v1 * 1);
    boost::math::legendre_next(2, v1 * 1, v2 + 0, v3 / 1);
    boost::math::legendre_next(2, 2, v1 * 1, v2 + 0, v3 / 1);
@@ -423,6 +479,11 @@ void instantiate(RealType)
    boost::math::laguerre_next(2, 1, v1 * 1, v2 + 0, v3 / 1);
    boost::math::hermite(1, v1 * 1);
    boost::math::hermite_next(2, v1 * 1, v2 + 0, v3 / 1);
+   boost::math::chebyshev_next(2 * v1, 1 + v2, 3 * v3);
+   boost::math::chebyshev_t(1, 2 * v1);
+   boost::math::chebyshev_u(1, 2 * v1);
+   boost::math::chebyshev_t_prime(1, 2 * v1);
+   boost::math::chebyshev_clenshaw_recurrence(&v1, 0, 2 * v2);
    boost::math::spherical_harmonic_r(2, 1, v1 * 1, v2 + 0);
    boost::math::spherical_harmonic_i(2, 1, v1 * 1, v2 + 0);
    boost::math::ellint_1(v1 * 1);
@@ -453,6 +514,18 @@ void instantiate(RealType)
    boost::math::jacobi_sc(v1 * 1, v2 + 0);
    boost::math::jacobi_sd(v1 * 1, v2 + 0);
    boost::math::jacobi_sn(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta1(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta1tau(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta2(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta2tau(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta3(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta3tau(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta3m1(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta3m1tau(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta4(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta4tau(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta4m1(v1 * 1, v2 + 0);
+   boost::math::jacobi_theta4m1tau(v1 * 1, v2 + 0);
    boost::math::hypot(v1 * 1, v2 + 0);
    boost::math::sinc_pi(v1 * 1);
    boost::math::sinhc_pi(v1 * 1);
@@ -461,6 +534,8 @@ void instantiate(RealType)
    boost::math::atanh(v1 * 1);
    boost::math::sin_pi(v1 * 1);
    boost::math::cos_pi(v1 * 1);
+#endif
+#ifdef TEST_GROUP_14
    boost::math::cyl_neumann(v1 * 1, v2 + 0);
    boost::math::cyl_neumann(i, v2 * 1);
    boost::math::cyl_bessel_j(v1 * 1, v2 + 0);
@@ -489,6 +564,9 @@ void instantiate(RealType)
    boost::math::cyl_bessel_j_zero(v1 * 1, i, i, oi);
    boost::math::cyl_neumann_zero(v1 * 1, i);
    boost::math::cyl_neumann_zero(v1 * 1, i, i, oi);
+   boost::math::lambert_w0(v1 * 1);
+   boost::math::lambert_wm1(v1 * 1);
+   boost::math::lambert_w0_prime(v1 * 1);
 #ifdef TEST_COMPLEX
    boost::math::cyl_hankel_1(v1, v2);
    boost::math::cyl_hankel_1(i, v2);
@@ -499,6 +577,8 @@ void instantiate(RealType)
    boost::math::sph_hankel_2(v1, v2);
    boost::math::sph_hankel_2(i, v2);
 #endif
+#endif
+#ifdef TEST_GROUP_15
    boost::math::airy_ai(v1 * 1);
    boost::math::airy_bi(v1 * 1);
    boost::math::airy_ai_prime(v1 * 1);
@@ -531,9 +611,12 @@ void instantiate(RealType)
    boost::math::float_next(v1 * 1);
    boost::math::float_prior(v1 * 1);
    boost::math::float_distance(v1 * 1, v1 * 1);
+   boost::math::ulp(v1 * 1);
+   boost::math::relative_difference(v1 * 1, v2 * 1);
+   boost::math::epsilon_difference(v1 * 1, v2 * 1);
 #endif
 #ifndef BOOST_MATH_INSTANTIATE_MINIMUM
-#ifdef TEST_GROUP_5
+#ifdef TEST_GROUP_8
    //
    // All over again, with a policy this time:
    //
@@ -586,6 +669,7 @@ void instantiate(RealType)
    boost::math::powm1(v1, v2, pol);
    boost::math::legendre_p(1, v1, pol);
    boost::math::legendre_p(1, 0, v1, pol);
+   boost::math::legendre_p_prime(1, v1 * 1, pol);
    boost::math::legendre_q(1, v1, pol);
    boost::math::legendre_next(2, v1, v2, v3);
    boost::math::legendre_next(2, 2, v1, v2, v3);
@@ -595,6 +679,9 @@ void instantiate(RealType)
    boost::math::laguerre_next(2, 1, v1, v2, v3);
    boost::math::hermite(1, v1, pol);
    boost::math::hermite_next(2, v1, v2, v3);
+   boost::math::chebyshev_t(1, v1, pol);
+   boost::math::chebyshev_u(1, v1, pol);
+   boost::math::chebyshev_t_prime(1, v1, pol);
    boost::math::spherical_harmonic_r(2, 1, v1, v2, pol);
    boost::math::spherical_harmonic_i(2, 1, v1, v2, pol);
    boost::math::ellint_1(v1, pol);
@@ -625,6 +712,18 @@ void instantiate(RealType)
    boost::math::jacobi_sc(v1, v2, pol);
    boost::math::jacobi_sd(v1, v2, pol);
    boost::math::jacobi_sn(v1, v2, pol);
+   boost::math::jacobi_theta1(v1, v2, pol);
+   boost::math::jacobi_theta1tau(v1, v2, pol);
+   boost::math::jacobi_theta2(v1, v2, pol);
+   boost::math::jacobi_theta2tau(v1, v2, pol);
+   boost::math::jacobi_theta3(v1, v2, pol);
+   boost::math::jacobi_theta3tau(v1, v2, pol);
+   boost::math::jacobi_theta3m1(v1, v2, pol);
+   boost::math::jacobi_theta3m1tau(v1, v2, pol);
+   boost::math::jacobi_theta4(v1, v2, pol);
+   boost::math::jacobi_theta4tau(v1, v2, pol);
+   boost::math::jacobi_theta4m1(v1, v2, pol);
+   boost::math::jacobi_theta4m1tau(v1, v2, pol);
    boost::math::hypot(v1, v2, pol);
    boost::math::sinc_pi(v1, pol);
    boost::math::sinhc_pi(v1, pol);
@@ -661,6 +760,9 @@ void instantiate(RealType)
    boost::math::cyl_bessel_j_zero(v1, i, i, oi, pol);
    boost::math::cyl_neumann_zero(v1, i, pol);
    boost::math::cyl_neumann_zero(v1, i, i, oi, pol);
+   boost::math::lambert_w0(v1, pol);
+   boost::math::lambert_wm1(v1, pol);
+   boost::math::lambert_w0_prime(v1, pol);
 #ifdef TEST_COMPLEX
    boost::math::cyl_hankel_1(v1, v2, pol);
    boost::math::cyl_hankel_1(i, v2, pol);
@@ -681,6 +783,21 @@ void instantiate(RealType)
    boost::math::airy_ai_zero<RealType>(i, i, oi, pol);
    boost::math::airy_bi_zero<RealType>(i, i, oi, pol);
 
+   boost::math::hypergeometric_1F0(i, v2, pol);
+   boost::math::hypergeometric_1F0(v1, i, pol);
+   boost::math::hypergeometric_1F0(i, i, pol);
+   boost::math::hypergeometric_0F1(i, v2, pol);
+   boost::math::hypergeometric_0F1(v1, i, pol);
+   boost::math::hypergeometric_0F1(i, i, pol);
+   boost::math::hypergeometric_2F0(i, v2, v3, pol);
+   boost::math::hypergeometric_2F0(v1, i, v3, pol);
+   boost::math::hypergeometric_2F0(v1, v2, i, pol);
+#if !defined(BOOST_NO_CXX11_AUTO_DECLARATIONS) && !defined(BOOST_NO_CXX11_LAMBDAS) && !defined(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX) && !defined(BOOST_NO_CXX11_HDR_TUPLE)
+   boost::math::hypergeometric_1F1(i, v2, v3, pol);
+   boost::math::hypergeometric_1F1(v1, i, v3, pol);
+   boost::math::hypergeometric_1F1(v1, v2, i, pol);
+#endif
+
    boost::math::expint(v1, pol);
    boost::math::expint(i, pol);
    boost::math::expint(i, v2, pol);
@@ -713,13 +830,14 @@ void instantiate(RealType)
    boost::math::float_next(v1, pol);
    boost::math::float_prior(v1, pol);
    boost::math::float_distance(v1, v1, pol);
+   boost::math::ulp(v1, pol);
 
    boost::math::bernoulli_b2n<RealType>(i, pol);
    boost::math::bernoulli_b2n<RealType>(i, i, &v1, pol);
    boost::math::tangent_t2n<RealType>(i, pol);
    boost::math::tangent_t2n<RealType>(i, i, &v1, pol);
 #endif
-#ifdef TEST_GROUP_6
+#ifdef TEST_GROUP_9
    //
    // All over again with the versions in test::
    //
@@ -780,6 +898,7 @@ void instantiate(RealType)
    test::powm1(v1, v2);
    test::legendre_p(1, v1);
    test::legendre_p(1, 0, v1);
+   test::legendre_p_prime(1, v1 * 1);
    test::legendre_q(1, v1);
    test::legendre_next(2, v1, v2, v3);
    test::legendre_next(2, 2, v1, v2, v3);
@@ -789,6 +908,11 @@ void instantiate(RealType)
    test::laguerre_next(2, 1, v1, v2, v3);
    test::hermite(1, v1);
    test::hermite_next(2, v1, v2, v3);
+   test::chebyshev_next(v1, v2, v3);
+   test::chebyshev_t(1, v1);
+   test::chebyshev_u(1, v1);
+   test::chebyshev_t_prime(1, v1);
+   test::chebyshev_clenshaw_recurrence(&v1, 0, v2);
    test::spherical_harmonic_r(2, 1, v1, v2);
    test::spherical_harmonic_i(2, 1, v1, v2);
    test::ellint_1(v1);
@@ -819,6 +943,18 @@ void instantiate(RealType)
    test::jacobi_sc(v1, v2);
    test::jacobi_sd(v1, v2);
    test::jacobi_sn(v1, v2);
+   test::jacobi_theta1(v1, v2);
+   test::jacobi_theta1tau(v1, v2);
+   test::jacobi_theta2(v1, v2);
+   test::jacobi_theta2tau(v1, v2);
+   test::jacobi_theta3(v1, v2);
+   test::jacobi_theta3tau(v1, v2);
+   test::jacobi_theta3m1(v1, v2);
+   test::jacobi_theta3m1tau(v1, v2);
+   test::jacobi_theta4(v1, v2);
+   test::jacobi_theta4tau(v1, v2);
+   test::jacobi_theta4m1(v1, v2);
+   test::jacobi_theta4m1tau(v1, v2);
    test::hypot(v1, v2);
    test::sinc_pi(v1);
    test::sinhc_pi(v1);
@@ -855,6 +991,9 @@ void instantiate(RealType)
    test::cyl_bessel_j_zero(v1, i, i, oi);
    test::cyl_neumann_zero(v1, i);
    test::cyl_neumann_zero(v1, i, i, oi);
+   test::lambert_w0(v1);
+   test::lambert_wm1(v1);
+   test::lambert_w0_prime(v1);
 #ifdef TEST_COMPLEX
    test::cyl_hankel_1(v1, v2);
    test::cyl_hankel_1(i, v2);
@@ -875,6 +1014,13 @@ void instantiate(RealType)
    test::airy_ai_zero<RealType>(i, i, oi);
    test::airy_bi_zero<RealType>(i, i, oi);
 
+   test::hypergeometric_1F0(v1, v2);
+   test::hypergeometric_0F1(v1, v2);
+   test::hypergeometric_2F0(v1, v1, v2);
+#if !defined(BOOST_NO_CXX11_AUTO_DECLARATIONS) && !defined(BOOST_NO_CXX11_LAMBDAS) && !defined(BOOST_NO_CXX11_UNIFIED_INITIALIZATION_SYNTAX) && !defined(BOOST_NO_CXX11_HDR_TUPLE)
+   test::hypergeometric_1F1(v1, v2, v2);
+#endif
+
    test::expint(v1);
    test::expint(i);
    test::expint(i, v2);
@@ -901,6 +1047,7 @@ void instantiate(RealType)
    test::float_next(v1);
    test::float_prior(v1);
    test::float_distance(v1, v1);
+   test::ulp(v1);
 #endif
 #endif
 }
@@ -912,16 +1059,23 @@ void instantiate_mixed(RealType)
    using namespace boost::math;
 #ifndef BOOST_MATH_INSTANTIATE_MINIMUM
    int i = 1;
+   (void)i;
    long l = 1;
+   (void)l;
    short s = 1;
+   (void)s;
    float fr = 0.5F;
+   (void)fr;
    double dr = 0.5;
+   (void)dr;
 #ifndef BOOST_MATH_NO_LONG_DOUBLE_MATH_FUNCTIONS
    long double lr = 0.5L;
+   (void)lr;
 #else
    double lr = 0.5L;
+   (void)lr;
 #endif
-#ifdef TEST_GROUP_7
+#ifdef TEST_GROUP_10
    boost::math::tgamma(i);
    boost::math::tgamma1pm1(i);
    boost::math::lgamma(i);
@@ -995,6 +1149,9 @@ void instantiate_mixed(RealType)
    boost::math::laguerre(2, 1, i);
    boost::math::laguerre(2u, 1u, s);
    boost::math::hermite(1, s);
+   boost::math::chebyshev_t(1, i);
+   boost::math::chebyshev_u(1, i);
+   boost::math::chebyshev_t_prime(1, i);
    boost::math::spherical_harmonic_r(2, 1, s, i);
    boost::math::spherical_harmonic_i(2, 1, fr, lr);
    boost::math::ellint_1(i);
@@ -1036,6 +1193,18 @@ void instantiate_mixed(RealType)
    boost::math::jacobi_sc(i, fr);
    boost::math::jacobi_sd(i, fr);
    boost::math::jacobi_sn(i, fr);
+   boost::math::jacobi_theta1(i, fr);
+   boost::math::jacobi_theta1tau(i, fr);
+   boost::math::jacobi_theta2(i, fr);
+   boost::math::jacobi_theta2tau(i, fr);
+   boost::math::jacobi_theta3(i, fr);
+   boost::math::jacobi_theta3tau(i, fr);
+   boost::math::jacobi_theta3m1(i, fr);
+   boost::math::jacobi_theta3m1tau(i, fr);
+   boost::math::jacobi_theta4(i, fr);
+   boost::math::jacobi_theta4tau(i, fr);
+   boost::math::jacobi_theta4m1(i, fr);
+   boost::math::jacobi_theta4m1tau(i, fr);
    boost::math::hypot(i, s);
    boost::math::hypot(fr, lr);
    boost::math::sinc_pi(i);
@@ -1143,6 +1312,9 @@ void instantiate_mixed(RealType)
    boost::math::laguerre(2, 1, i, pol);
    boost::math::laguerre(2u, 1u, s, pol);
    boost::math::hermite(1, s, pol);
+   boost::math::chebyshev_t(1, i, pol);
+   boost::math::chebyshev_u(1, i, pol);
+   boost::math::chebyshev_t_prime(1, i, pol);
    boost::math::spherical_harmonic_r(2, 1, s, i, pol);
    boost::math::spherical_harmonic_i(2, 1, fr, lr, pol);
    boost::math::ellint_1(i, pol);
@@ -1184,6 +1356,18 @@ void instantiate_mixed(RealType)
    boost::math::jacobi_sc(i, fr, pol);
    boost::math::jacobi_sd(i, fr, pol);
    boost::math::jacobi_sn(i, fr, pol);
+   boost::math::jacobi_theta1(i, fr, pol);
+   boost::math::jacobi_theta1tau(i, fr, pol);
+   boost::math::jacobi_theta2(i, fr, pol);
+   boost::math::jacobi_theta2tau(i, fr, pol);
+   boost::math::jacobi_theta3(i, fr, pol);
+   boost::math::jacobi_theta3tau(i, fr, pol);
+   boost::math::jacobi_theta3m1(i, fr, pol);
+   boost::math::jacobi_theta3m1tau(i, fr, pol);
+   boost::math::jacobi_theta4(i, fr, pol);
+   boost::math::jacobi_theta4tau(i, fr, pol);
+   boost::math::jacobi_theta4m1(i, fr, pol);
+   boost::math::jacobi_theta4m1tau(i, fr, pol);
    boost::math::hypot(i, s, pol);
    boost::math::hypot(fr, lr, pol);
    boost::math::sinc_pi(i, pol);
@@ -1219,8 +1403,11 @@ void instantiate_mixed(RealType)
    boost::math::sph_neumann_prime(i, i, pol);
    boost::math::owens_t(fr, dr, pol);
    boost::math::owens_t(i, s, pol);
+   boost::math::lambert_w0(i, pol);
+   boost::math::lambert_wm1(i, pol);
+   boost::math::lambert_w0_prime(i, pol);
 #endif
-#ifdef TEST_GROUP_8
+#ifdef TEST_GROUP_11
    test::tgamma(i);
    test::tgamma1pm1(i);
    test::lgamma(i);
@@ -1294,6 +1481,9 @@ void instantiate_mixed(RealType)
    test::laguerre(2, 1, i);
    test::laguerre(2u, 1u, s);
    test::hermite(1, s);
+   test::chebyshev_t(1, i);
+   test::chebyshev_u(1, i);
+   test::chebyshev_t_prime(1, s);
    test::spherical_harmonic_r(2, 1, s, i);
    test::spherical_harmonic_i(2, 1, fr, lr);
    test::ellint_1(i);
@@ -1362,10 +1552,12 @@ void instantiate_mixed(RealType)
    test::airy_bi_prime(i);
    test::owens_t(fr, dr);
    test::owens_t(i, s);
+   boost::math::lambert_w0(i);
+   boost::math::lambert_wm1(i);
+   boost::math::lambert_w0_prime(i);
 #endif
 #endif
 }
 
 
 #endif // BOOST_LIBS_MATH_TEST_INSTANTIATE_HPP
-
